package pdf

import "testing"

// TestIsWhitespace tests the isWhitespace function.
func TestIsWhitespace(t *testing.T) {
	whitespaceChars := []rune{0x00, 0x09, 0x0A, 0x0C, 0x0D, 0x20}
	nonWhitespaceChars := []rune{'a', '1', '!', '(', ')', 'Ͱ', '￿', ' ', '　', ' '}

	// Test all valid whitespace characters.
	for _, ch := range whitespaceChars {
		if !isWhitespace(ch) {
			t.Errorf("Expected isWhitespace(%q) to be true, got false", ch)
		}
	}

	// Test some characters that are not whitespace.
	for _, ch := range nonWhitespaceChars {
		if isWhitespace(ch) {
			t.Errorf("Expected isWhitespace(%q) to be false, got true", ch)
		}
	}
}

// TestIsDelimiter tests the isDelimiter function.
func TestIsDelimiter(t *testing.T) {
	delimiterChars := []rune{'(', ')', '<', '>', '[', ']', '/', '%'}
	nonDelimiterChars := []rune{'a', '1', ' ', '!', 'x', 'Ͱ', '￿'}

	// Test all valid delimiter characters.
	for _, ch := range delimiterChars {
		if !isDelimiter(ch) {
			t.Errorf("Expected isDelimiter(%q) to be true, got false", ch)
		}
	}

	// Test some characters that are not delimiters.
	for _, ch := range nonDelimiterChars {
		if isDelimiter(ch) {
			t.Errorf("Expected isDelimiter(%q) to be false, got true", ch)
		}
	}
}

func TestIsLeftParenthesis(t *testing.T) {
	charsThatShouldBeTrue := []rune{'('}
	charsThatShouldBeFalse := []rune{')', '<', '>', '[', ']', '/', '%', 'a', '1', ' ', '!', 'x', 'Ͱ', '￿'}

	for _, ch := range charsThatShouldBeTrue {
		if !isLeftParenthesis(ch) {
			t.Errorf("Expected isLeftParenthesis(%q) to be true, got false", ch)
		}
	}

	for _, ch := range charsThatShouldBeFalse {
		if isLeftParenthesis(ch) {
			t.Errorf("Expected isLeftParenthesis(%q) to be false, got true", ch)
		}
	}
}
