package pdf

import "strconv"

type byteOffsetOfLastCrossReferenceSectionState struct {
	token *xrefToken
}

func (s byteOffsetOfLastCrossReferenceSectionState) process(t *Tokenizer) {

	if s.token == nil {
		t.raiseError(ErrorTokenNil)
		return
	}

	for {

		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfFile(c) {
			t.raiseError(ErrUnexpectedEOF)
			return
		}

		if isEndOfLine(c) {

			o, err := strconv.ParseInt(string(s.token.values), 10, 64)
			if err != nil {
				t.raiseError(err)
				return
			}

			s.token.byteOffsetXRef = o
			t.emitToken(s.token)

			t.switchState(endOfLineState{
				token: &endOfLineToken{},
			})
			break
		}

		if !isNumeric(c) {
			t.raiseError(ErrInvalidByteOffset)
			return
		}

		s.token.values = append(s.token.values, c)

	}

	return

}
