package pdf

import (
	"io"
	"testing"
)

func TestByteOffsetLastCrossReferenceSectionState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"No numeric value", "x", byteOffsetOfLastCrossReferenceSectionState{}, ErrInvalidByteOffset, []tokenInterface{}},
		{"numeric value", "1234", byteOffsetOfLastCrossReferenceSectionState{}, io.EOF, []tokenInterface{}},
		{"numeric value with linefeed", "1234\n", endOfLineState{}, io.EOF, []tokenInterface{&xrefToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = byteOffsetOfLastCrossReferenceSectionState{
				token: &xrefToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}

func TestByteOffsetLastCrossReferenceSectionStateValue(t *testing.T) {
	tok := createTestTokenizerWithData("1\n")
	tok.state = byteOffsetOfLastCrossReferenceSectionState{
		token: &xrefToken{},
	}

	// Verarbeite den Tokenizer
	tok.state.process(tok)

	checkStateAgainstDef(t, tok, endOfLineState{})
	checkErrors(t, tok, io.EOF)
	checkTokenStack(t, tok, []tokenInterface{&xrefToken{}})

	if tok.getLastToken().(*xrefToken).byteOffsetXRef != 1 {
		t.Errorf("Expected byte offset to be 1, got %d", tok.getLastToken().(*xrefToken).byteOffsetXRef)
	}

}
