package pdf

type endOfFileToken struct {
	tokenInternal
}

type endOfFileState struct {
	token *endOfFileToken
}

func (s endOfFileState) process(t *Tokenizer) {

	if s.token == nil {
		s.token = &endOfFileToken{}
	}

	for {
		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfFile(c) {
			t.raiseError(ErrUnexpectedEOF)
			return
		}

		if c == 'E' || c == 'O' || c == 'F' || isPercentSign(c) {

			s.token.values = append(s.token.values, c)
			continue
		}

		err = t.unread()
		if err != nil {
			t.raiseError(err)
			return
		}
		break

	}

	if string(s.token.values) != EndOfFileMagicNumber {
		err := t.unreadCount(len(s.token.values))
		if err != nil {
			t.raiseError(err)
			return
		}
		return
	}

	t.emitToken(s.token)

	t.switchState(endOfLineState{
		token: &endOfLineToken{},
	})

}
