package pdf

type fileHeaderToken struct {
	tokenInternal
}

type fileHeaderState struct {
	token *fileHeaderToken
}

func (s fileHeaderState) process(t *Tokenizer) {
	for {

		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		// End of the file
		if isEndOfFile(c) {
			t.raiseError(ErrUnexpectedEOF)
			return
		}

		if c == 'P' || c == 'D' || c == 'F' || c == '-' {
			s.token.values = append(s.token.values, c)
			continue
		}
		break
	}

	if s.token == nil {
		t.raiseError(ErrInvalidPDFMagicNumber)
		return
	}

	if string(s.token.values) != MagicNumber {
		t.raiseError(ErrInvalidPDFMagicNumber)
		return
	}

	t.emitToken(s.token)

	err := t.unread()
	if err != nil {
		t.raiseError(err)
		return
	}

	t.switchState(pdfVersionState{
		token: &pdfVersionToken{},
	})

}
