package pdf

import (
	"testing"
)

func TestFileHeaderState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"PDF Version 2.0 with an end of line", "2.0\r\n", fileHeaderState{}, ErrInvalidPDFMagicNumber, []tokenInterface{}},
		{"PDF Version 2.0 with an end of line", "PDF-2.0\r\n", endOfLineState{}, nil, []tokenInterface{&fileHeaderToken{}, &pdfVersionToken{}, &endOfLineToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = fileHeaderState{
				token: &fileHeaderToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}

func TestFileHeaderTokenIsNil(t *testing.T) {
	tok := createTestTokenizerWithData("2.0\r\n")
	tok.state = fileHeaderState{}

	// Verarbeite den Tokenizer
	tok.state.process(tok)

	if !tok.HasError() {
		t.Errorf("Expected error, got none")
	}
}
