package pdf

import "fmt"

type identifyLineTypeState struct {
}

func (s identifyLineTypeState) process(t *Tokenizer) {

	buffer := ""

	for {
		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfFile(c) {
			return
		}

		if isEndOfLine(c) {
			t.switchState(endOfLineState{
				token: &endOfLineToken{},
			})
			break
		}

		if isPercentSign(c) {

			eofToken := &endOfFileToken{}

			t.switchState(endOfFileState{
				token: eofToken,
			})

			if eofToken.isEmitted() {
				return
			}

			t.switchState(commentState{
				token: &commentToken{},
			})

			continue

		}

		buffer += string(c)

		switch buffer {
		case keywordStartObj:
			fmt.Println("OBJ")
		case keywordEndObj:
			fmt.Println("ENDOBJ")
		case keywordStartStream:
			fmt.Println("STREAM")
		case keywordEndStream:
			fmt.Println("ENDSTREAM")
		case keywordStartXRef:
			t.switchState(xrefState{
				token: &xrefToken{},
			})
		case keywordStartTrailer:
			t.switchState(trailerStartState{
				token: &trailerToken{},
			})

		}

	}
}
