package pdf

import "io"

type initialState struct{}

func (s initialState) process(t *Tokenizer) {

	// NOTE 1 This provision allows for arbitrary bytes preceding the `%PDF-` without impacting the viability of
	// the PDF file and its byte offsets.
	for {
		c, err := t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isPercentSign(c) {
			t.byteOffset = 0
			t.switchState(fileHeaderState{
				token: &fileHeaderToken{},
			})

			c, err = t.consumeNextRune()
			if err != nil {
				t.raiseError(err)
				return
			}
			err = t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}

			t.switchState(runBodyState{})
			break
		}

		if isEndOfFile(c) {
			t.raiseError(io.EOF)
			return
		}

	}

}
