package pdf

import (
	"strconv"
)

type nameToken struct {
	tokenInternal
	value string
}

type readNameObjectState struct {
	token *nameToken
}

func (s readNameObjectState) process(t *Tokenizer) {

	var c rune
	var err error

	var value string

	c, err = t.consumeNextRune()
	if err != nil {
		t.raiseError(err)
		return
	}

	if isEndOfFile(c) {
		t.raiseError(ErrUnexpectedEOF)
		return
	}

	// The SOLIDUS is not part of the name
	if !isSolidus(c) {
		t.raiseError(ErrInvalidName)
		return
	}

	for {
		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isWhitespace(c) || isDelimiter(c) {
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}
			break
		}

		// A NUMBER SIGN (23h) (#) in a name shall be written by using its 2-digit hexadecimal code (23),
		// preceded by the NUMBER SIGN.
		if c == '#' {
			var hex string
			for i := 0; i < 2; i++ {
				c, err = t.consumeNextRune()
				if err != nil {
					t.raiseError(err)
					return
				}
				if !isHexDigit(c) {
					t.raiseError(ErrInvalidHexDigit)
					return
				}
				hex += string(c)
			}
			decodedChar, err := strconv.ParseInt(hex, 16, 8)
			if err != nil {
				t.raiseError(err)
				return
			}
			value += string(rune(decodedChar))
			continue
		}

		value += string(c)

	}

	s.token.value = value
	t.emitToken(s.token)

	return
}

func isHexDigit(c rune) bool {
	return ('0' <= c && c <= '9') || ('a' <= c && c <= 'f') || ('A' <= c && c <= 'F')
}
