package pdf

type numberToken struct {
	tokenInternal
	value   string
	hasDot  bool
	hasSign bool
}

type readNumberObjectState struct {
	token *numberToken
}

// https://github.com/pdf-association/pdf-issues/issues/300
// NOTE: PDF permits multiple leading 0 digits in numeric objects,
// EXAMPLE 1 add: -00123
// EXAMPLE 2 add: -001.23
func (s readNumberObjectState) process(t *Tokenizer) {

	var c rune
	var err error

	var value string
	firstRuneFlag := true
	hasDot := false

	for {

		c, err = t.consumeNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		if isEndOfFile(c) {
			t.raiseError(ErrUnexpectedEOF)
			return
		}

		if c == '.' && !hasDot {
			hasDot = true
			value += string(c)
			firstRuneFlag = false
			continue
		}

		if firstRuneFlag && (c == '+' || c == '-') {
			value += string(c)
			firstRuneFlag = false
			continue
		}
		firstRuneFlag = false

		if !isNumeric(c) {
			err := t.unread()
			if err != nil {
				t.raiseError(err)
				return
			}
			break
		}

		value += string(c)
	}

	if value == "" || value == "-" || value == "+" || value == "." {
		t.raiseError(ErrInvalidNumber)
		return
	}

	s.token.value = value
	s.token.hasDot = hasDot

	t.emitToken(s.token)

	return
}
