package pdf

import (
	"io"
	"testing"
)

func TestReadNumberObjectStateProcess(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"empty", "", readNumberObjectState{}, io.EOF, []tokenInterface{}},
		{"simple integer", "1", readNumberObjectState{}, io.EOF, []tokenInterface{}},
		{"Not a Number", "A", readNumberObjectState{}, ErrInvalidNumber, []tokenInterface{}},
		{"Number plus Char ", "1A", readNumberObjectState{}, nil, []tokenInterface{}},
		{"multiple plus", "++", readNumberObjectState{}, ErrInvalidNumber, []tokenInterface{}},
		{"multiple minus", "--", readNumberObjectState{}, ErrInvalidNumber, []tokenInterface{}},
		{"dot and plus", ".+", readNumberObjectState{}, ErrInvalidNumber, []tokenInterface{}},
		{"float", "1.", readNumberObjectState{}, io.EOF, []tokenInterface{}},
		{"float dot number", "1.0", readNumberObjectState{}, io.EOF, []tokenInterface{}},
		{"dot number", ".0", readNumberObjectState{}, io.EOF, []tokenInterface{}},
		{"dot number linefeed", ".0\n", readNumberObjectState{}, nil, []tokenInterface{}},
		{"dot number dot", ".0.", readNumberObjectState{}, nil, []tokenInterface{}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = readNumberObjectState{
				token: &numberToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
