package pdf

import (
	"unicode"
)

type startValueState struct {
}

func (s startValueState) process(t *Tokenizer) {

	for {

		c, err := t.peekNextRune()
		if err != nil {
			t.raiseError(err)
			return
		}

		// Bestimme den Typ basierend auf der ersten Nicht-Whitespace-Rune
		switch {
		case unicode.IsDigit(c) || c == '+' || c == '-':
			t.switchState(readNumberObjectState{
				token: &numberToken{},
			})

		case isLeftParenthesis(c):
			t.switchState(readStringObjectState{
				token: &stringToken{},
			})
		case isLessThanSign(c):
			t.switchState(readStringObjectState{
				token: &stringToken{},
			})
		case isSolidus(c):
			t.switchState(readNameObjectState{
				token: &nameToken{},
			})

		case isLeftSquareBracket(c):

			t.switchState(startArrayObjectState{
				token: &arrayStartToken{},
			})

		case c == 't' || c == 'f':
			t.switchState(readBooleanObjectState{
				token: &booleanToken{},
			})

		case c == 'n':

			t.switchState(readNullObjectState{
				token: &nullToken{},
			})

		case isLeftSquareBracket(c):
			t.switchState(startArrayObjectState{
				token: &arrayStartToken{},
			})
		// @todo: implement dictionary object
		//case isLeftCurlyBracket(c):
		//	t.switchState(startDictionaryObjectState{
		//		token: &dictionaryStartToken{},
		//	})
		//case c == 'R':
		//	t.switchState(readIndirectObjectState{
		//		token: &indirectObjectToken{},
		//	})
		case isWhitespace(c): // array or dictionary may contain whitespace
			return

		default:
			t.raiseError(ErrUnknownValueType)
			return
		}

	}
}
