package pdf

import (
	"io"
	"testing"
)

func TestTrailerStartState(t *testing.T) {

	tests := []struct {
		name          string
		input         string
		expectedState state
		expectedError error
		expectTokens  []tokenInterface
	}{
		{"Only whitespaces", "   ", whitespaceState{}, io.EOF, []tokenInterface{&whitespaceToken{}}},
		{"Simple Trailer example", "trailer\n<<\n/Size 22\n/Root 1 0 R\n/Info 2 0 R\n>>\nstartxref\n123456\n%%EOF\n", whitespaceState{}, io.EOF, []tokenInterface{&whitespaceToken{}}},
	}

	for _, tt := range tests {
		t.Run(tt.name, func(t *testing.T) {
			tok := createTestTokenizerWithData(tt.input)
			tok.state = trailerStartState{
				token: &trailerToken{},
			}

			// Verarbeite den Tokenizer
			tok.state.process(tok)

			checkStateAgainstDef(t, tok, tt.expectedState)
			checkErrors(t, tok, tt.expectedError)
			checkTokenStack(t, tok, tt.expectTokens)

		})
	}
}
